"""
CMFO Logic Module
=================

Fractal logic operations.
"""

from .fractal_logic import TRUE, FALSE, NEUTRAL, f_not, f_and, f_or, f_xor

__all__ = ['TRUE', 'FALSE', 'NEUTRAL', 'f_not', 'f_and', 'f_or', 'f_xor']
